## Python обертка для запросов в БД [Clickhouse](https://clickhouse.yandex/)

## Установка
```
pip install clickhousepy
```

## Зависимости
- [clickhouse-driver](https://github.com/mymarilyn/clickhouse-driver/)
- [pandas](https://github.com/pandas-dev/pandas)
